/*----------------------------------------------------------------------------
FILE NAME:     array.cpp

AUTHOR:        Stefano Basagni

CREATED:       January 2003

DESCRIPTION:   Example of a simple C++ program to test functions on arrays.

---
Copyright (C) 2003 Stefano Basagni

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

To receive a copy of the GNU General Public License write to
the Free Software Foundation, Inc., 59 Temple Place - Suite
330, Boston, MA 02111-1307, USA.

Stefano Basagni can be contacted at basagni@ece.neu.edu.

----------------------------------------------------------------------------*/
// INCLUDE SECTION
#include <iomanip.h>
#include <math.h>
#include <algo.h>

// Pseudo-random number generation
#include "rstream.h"

// CONSTANT SECTION
const int MAXINT = 65536;

// PROTOTYPES
// Initialize and array with random integer numbers
void initR( int A[], int n );

void printArray( int A[], int n );

//---------------------------------------------------------------------
// MAIN
int main() {

  int nn = 10;
  int AA[ nn ];  

  for( int a = 0; a < 10; a++ ) {
    initR( AA, nn );
    printArray( AA, nn );
  }

  return 0;

}
  

//---------------------------------------------------------------------
// FUNCTION DEFS
//---------------------------------------------------------------------
// Initialize and array with random integer numbers
void initR( int A[], int n ) {
  // Random stream for the positions
  static Rstream aElem( 1965 );
  for( int a = 0; a < n ; a++ ) 
	 A[ a ] = aElem.uniform_discrete( -MAXINT, MAXINT );
}

//---------------------------------------------------------------------
// Print an array of n elements 
void printArray( int A[], int n ) {
  cout << "The array is: ";
  for( int a = 0; a < n; a++ )
    cout << A[ a ] << " ";
  cout << endl;
}
